<?php

namespace Drupal\search_api_opensolr\OpenSolrApi\Components;

use Drupal\search_api_opensolr\OpenSolrApi\OpenSolrBase;

/**
 * Class OpenSolrIndex.
 *
 * @todo: Improve the way we handle the responses.
 *
 * @package Drupal\search_api_opensolr\OpenSolrApi\Components
 */
class OpenSolrIndex extends OpenSolrBase implements OpenSolrIndexInterface {

  /**
   * {@inheritdoc}
   */
  public function getIndexList(array $params = []) {
    $result = [];

    $indexes = $this->apiCall('/get_index_list', 'GET', $params);
    if (is_array($indexes) && !isset($indexes['status'])) {
      foreach ($indexes as $index) {
        $result[$index] = $index;
      }

      return $result;
    }

    return $indexes;
  }

  /**
   * {@inheritdoc}
   */
  public function getCoreInfo($coreName) {
    $result = [];

    $params = ['core_name' => $coreName];
    $coreInfo = $this->apiCall('/get_core_info', 'GET', $params);
    if (isset($coreInfo['status']) && $coreInfo['status'] === TRUE) {
      $result = !empty($coreInfo['msg']) && is_array($coreInfo['msg']) ? $coreInfo['msg'] : [];
    }

    return $result;
  }

  /**
   * {@inheritdoc}
   */
  public function reloadCore($coreName) {
    $params = ['core_name' => $coreName];
    $coreReload = $this->apiCall('/reload_core', 'GET', $params);
    if (isset($coreReload['status']) && $coreReload['status'] === TRUE) {
      return TRUE;
    }

    return $coreReload;
  }

  /**
   * {@inheritdoc}
   */
  public function optimizeCore($coreName) {
    $params = ['core_name' => $coreName];
    $coreOptimize = $this->apiCall('/optimize', 'GET', $params);
    if (isset($coreOptimize['status']) && $coreOptimize['status'] === TRUE) {
      return TRUE;
    }

    return $coreOptimize;
  }

  /**
   * {@inheritdoc}
   */
  public function commitData($coreName) {
    $params = ['core_name' => $coreName];
    $coreCommit = $this->apiCall('/commit', 'GET', $params);
    if (isset($coreCommit['status']) && $coreCommit['status'] === TRUE) {
      return TRUE;
    }

    return $coreCommit;
  }

  /**
   * {@inheritdoc}
   */
  public function getCoreStatus($coreName) {
    $params = ['core_name' => $coreName];
    $coreStatus = $this->apiCall('/get_core_status', 'GET', $params);
    if (isset($coreStatus['status']) && $coreStatus['status'] === TRUE) {
      return $this->json->decode($coreStatus['msg']);
    }

    return $coreStatus;
  }

  /**
   * {@inheritdoc}
   */
  public function createCore($coreName, $serverCountry, $mode = 'standalone', $coreType = 'generic') {
    $params = [
      'core_name' => $coreName,
      'mode' => $mode,
      'core_type' => $coreType,
      'server_country' => $serverCountry,
    ];
    $coreCreate = $this->apiCall('/create_core', 'GET', $params);

    return $coreCreate;
  }

  /**
   * {@inheritdoc}
   */
  public function deleteCore($coreName) {
    $params = ['core_name' => $coreName];
    $coreDelete = $this->apiCall('/delete_core', 'GET', $params);
    if (isset($coreDelete['status']) && $coreDelete['status'] === TRUE) {
      return TRUE;
    }

    return $coreDelete;
  }

  /**
   * {@inheritdoc}
   */
  public function replicateIndex($coreName, $targetIndex) {
    // @todo: Need to wait for API update.
    $params = ['core_name' => $coreName, 'target_index' => $targetIndex];
    $coreReplicate = $this->apiCall('/replicate_index', 'GET', $params);

    return $coreReplicate;
  }

}
