<?php

namespace Drupal\search_api_opensolr;

use Drupal\Core\DependencyInjection\ContainerInjectionInterface;
use Drupal\search_api\ServerInterface;
use Drupal\search_api_opensolr\Services\ZipManager;
use Drupal\search_api_opensolr\Traits\OpensolrServerTrait;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Defines a class for reacting to server events.
 *
 * @internal
 */
class ServerOperations implements ContainerInjectionInterface {
  use OpensolrServerTrait;

  /**
   * The opensolr zip manager service.
   *
   * @var \Drupal\search_api_opensolr\Services\ZipManager
   */
  protected $zipManager;

  /**
   * Constructs a new EntityOperations object.
   *
   * @param \Drupal\search_api_opensolr\Services\ZipManager $zipManager
   *   The opensolr zip manager service.
   */
  public function __construct(ZipManager $zipManager) {
    $this->zipManager = $zipManager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('search_api_opensolr.zip_manager')
    );
  }

  /**
   * Reacts on server insert events.
   *
   * @param \Drupal\search_api\ServerInterface $server
   *   The newly created server.
   *
   * @throws \Drupal\search_api\SearchApiException
   * @see hook_entity_insert()
   */
  public function serverInsert(ServerInterface $server) {
    if ($this->isOpenSolrServer($server)) {
      $this->zipManager->importConfigZip($server);
    }
  }

}
